{% if title and label %}
  <a id="start_btn_{{ wrapped_appointment.visit_code }}_{{ wrapped_appointment.visit_code_sequence }}"
     role="button" data-toggle="tooltip"
     title="{{ title }}" {% if wrapped_appointment.object.site.id != request.site.id %} disabled {% endif %}
     class="btn btn-sm btn-{{ btn_class|default:'default' }}" href="{% if wrapped_appointment.object.site.id != request.site.id %}#{% else %}{{ wrapped_appointment.href }}{% endif %}"> {{ label }}
  </a>
{% endif %}
